@@ -9,6 +9,11 @@ class AdministrationUtility(dm.cli.admin.AdministrationUtility):
     def buildApplication(self):
         import kforge.soleInstance
 
+    def initialiseSystemServiceFilesystem(self):
+        import kforge.cli.data
+        installer = kforge.cli.data.InstallData()
+        installer.execute()
+
     def do_data(self, line=None):
         args = self.convertLineToArgs(line)
         if len(args) == 0:
@@ -22,17 +27,84 @@ class AdministrationUtility(dm.cli.admin.AdministrationUtility):
             self.help_data()
             return 1
 
-    def initialiseSystemServiceFilesystem(self):
-        import kforge.cli.data
-        installer = kforge.cli.data.InstallData()
-        installer.execute()
-
     def help_data(self, line=None):
         usage = \
 '''data create 
 
 Install environment data including templates, htdocs, media. The values
 in your configuration will be used to create filesystem files.
+'''
+        print usage
+
+    def do_plugin(self, line=None):
+        args = self.convertLineToArgs(line)
+
+        if len(args) == 0:
+            print 'ERROR: Insufficient arguments\n'
+            self.help_plugin(line)
+            return 1
+        actionName = args[0]
+        if len(args) > 1:
+            pluginName = args[1]
+        else:
+            pluginName = ''
+
+        import kforge.soleInstance
+        registry = kforge.soleInstance.application.registry
+        from dm.ioc import RequiredFeature
+        pluginFactory = RequiredFeature('PluginFactory')
+        plugin_points = pluginFactory.getEntryPoints()
+
+        # TODO: could list which plugins are already installed using register
+        if actionName == 'list':
+            for en in plugin_points:
+                print en.name
+            return 0
+
+        if not pluginName:
+            print 'ERROR: Plugin name required. See command help for details.'
+            return 1
+        if actionName == 'enable':
+            registry.plugins.create(pluginName)
+            msg = \
+'''SUCCESS.
+
+Please note that for this plugin to be fully operational you may need to
+install some additional software. For more information please see the plugin's
+documentation:
+
+    kforge-admin plugin doc %s
+''' % pluginName
+            print msg
+            return 0
+        elif actionName == 'disable':
+            del(registry.plugins[pluginName])
+            return 0
+        elif actionName == 'doc':
+            # bit of a hack until we move docstring into plugin class from
+            # module
+            plugin_system = pluginFactory.getPluginClass(pluginName)
+            pluginPackage = __import__(plugin_system.__module__, '', '', '*')
+            print pluginPackage.__doc__
+            return 0
+        else:
+            self.help_plugin()
+            return 1
+
+    def help_plugin(self, line=None):
+        usage = \
+'''plugin {action} [plugin-name]
+
+{action} is one of: list | doc | enable | disable
+
+  * list: list the plugins installed on the system and thus available for use
+    with this service (so all plugins available whether enabled or disabled).
+  * doc: documentation on the specified plugin including details of any
+    additional software that needs to be installed to use the plugin's
+    functionality.
+  * enable: enable the specified plugin on this KForge service.
+  * disable: disable the specified plugin on this KForge service. Warning: you
+    will not be able to delete a plugin if it has any associated services.
 '''
         print usage
 
@@ -71,15 +143,9 @@ in your configuration will be used to create filesystem files.
         # nothing in fact to do
         print 'No changes required.'
 
-    def buildApacheConfig(self):
+    def getApacheConfigBuilderClass(self):
         from kforge.apache.apacheconfig import ApacheConfigBuilder
-        configBuilder = ApacheConfigBuilder()
-        configBuilder.buildConfig()
-
-    def reloadApacheConfig(self):
-        from kforge.apache.apacheconfig import ApacheConfigBuilder
-        configBuilder = ApacheConfigBuilder()
-        configBuilder.reloadConfig()
+        return ApacheConfigBuilder
 
     def getSystemName(self):
         return "KForge"
