@@ -1,6 +1,5 @@
 from webunit import webunittest
 import unittest
-import kforge.django.apps.kui.views.test
 from kforge.django.apps.kui.test.base import KuiTestCase
 import kforge.django.apps.kui.test.admin
 import kforge.django.apps.kui.test.person
@@ -10,7 +9,6 @@ import kforge.django.apps.kui.test.service
 
 def suite():
     suites = [
-        kforge.django.apps.kui.views.test.suite(),
         unittest.makeSuite(TestVisitServer),
         kforge.django.apps.kui.test.admin.suite(),
         kforge.django.apps.kui.test.person.suite(),
@@ -23,8 +21,10 @@ def suite():
 class TestVisitServer(KuiTestCase):
    
     def testHome(self):
-        self.getAssertContent('/', 'Welcome to')
+        offset = self.url_scheme.url_for('home')
+        self.getAssertContent(offset, 'Welcome to')
     
     def testUserLogin(self):
-        self.getAssertContent('/login/', 'Log in')
+        offset = self.url_scheme.url_for('login')
+        self.getAssertContent(offset, 'Log in')
 
