@@ -39,3 +39,6 @@ class Project(StandardObject):
             member.purge()
         super(Project, self).purge()
 
+    def getLabelValue(self):
+        return self.title or self.name
+
