@@ -152,22 +152,16 @@ class PythonAccessHandler(ModPythonHandler):
         return ''
             
     def setLoginRedirect(self):
-        domain_name = self.app.dictionary['domain_name']
-        port_http = self.app.dictionary['www.port_http']
-        if port_http == '80':
-            portString = ''
-        else:
-            portString = ':' + port_http
+        import kforge.url
+        url_scheme = kforge.url.UrlScheme()
         if self.session:
-            redirectUri = 'http://admin.%s%s/accessDenied/' % (
-                domain_name, portString
-            )
+            redirectUri = url_scheme.url_for_qualified('access_denied') 
+            redirectUri += '/'
         else:
-            redirectUri = 'http://admin.%s%s/login/' % (
-                domain_name, portString
-            )
-        redirectUri += 'http://project.%s%s' % (domain_name, portString)
-        redirectUri += self.request.uri
+            redirectUri = url_scheme.url_for_qualified('login') 
+            redirectUri += '/'
+        current_uri = url_scheme.get_host() + self.request.uri
+        redirectUri += current_uri
         self.request.err_headers_out.add('Location', redirectUri)
         if self.app.debug:
             self.loggerDebug('Redirecting to %s.' % redirectUri)
@@ -177,10 +171,13 @@ class PythonAccessHandler(ModPythonHandler):
 class PythonAuthenHandler(ModPythonHandler):
 
     def initAuthuserNameFromBasicPrompt(self):
+        pw = self.request.get_basic_auth_pw()
+        if self.app.debug:
+            self.loggerDebug('Running initAuthuserNameFromBasicPrompt. Current user is %s.' % self.request.user)
         import kforge.apache.urlpermission as urlpermission
         self.authuserName = urlpermission.getVisitorName(
             self.request.user,
-            self.request.get_basic_auth_pw()
+            pw
         )
         self.request.user = self.authuserName
 
