@@ -1,6 +1,8 @@
 """
-KForge Mailman plugin. Enabling this plugin allows users to create mailman
-services to provide mailing lists associated with their project.
+KForge Mailman plugin.
+
+Installing this plugin allows users to create mailman services to provide
+mailing lists associated with their project.
 
 ## Installation ##
 
@@ -8,7 +10,8 @@ services to provide mailing lists associated with their project.
 have mailman web interface running (see the mailman installation instructions
 for how to set this up).
 
-2. Add the following configuration to your kforge configuration file
+2. KForge config file. Add the following to your KForge configuration file
+   setting the variables as needed for your system:
 
 [mailman]
 # set this to the fully qualified domain name for your mailing lists
@@ -28,8 +31,8 @@ rmlist = sudo rmlist
 # this is the password that will be used for new mailing lists
 list_admin_password = change_this_password_immediately 
 
-3. Install and enable this plugin in the usual way (see the KForge
-Documentation for details)
+3. Install and enable this plugin in the usual way (see the KForge Guide
+   for details).
 """
 import os
 import commands
