@@ -1,18 +1,25 @@
 """
-Plugin to provide moinmoin wiki services.
+KForge MoinMoin plugin.
 
-This Plugin was tested against moinmoin v1.3 but should worked with later
-versions.
+Installing this plugin allows users to create moinmoin services to provide
+moinmoin wikis associated with their project.
+
+This Plugin has been tested against moinmoin v1.3 and v1.5 but should worked with later versions.
 
 ## Installation
 
-1. Add the following to your kforge.conf file
+1. To create services using this plugin you must have installed the following
+   external applications:
+
+   * moinmoin
+
+2. Add the following to your kforge.conf file
 
 [moin]
 # where moin system data is installed (htdocs etc)
 system_path = /usr/share/moin
 
-2. This plugin will copy data from that location in order to create each new
+3. This plugin will copy data from that location in order to create each new
 wiki (see MoinUtils below). A couple of changes that may be required:
 
     1. This plugin mounts the moinmoin htdocs at /moinhtdocs. You will
@@ -22,8 +29,8 @@ wiki (see MoinUtils below). A couple of changes that may be required:
     2. Any other wikiconfig variables that you want to be same in all the
     kforge services you should set in the master wikiconfig.py.
 
-3. Enable this plugin (see the Kforge guide for details if you do not know how
-to do this)
+3. Install and enable this plugin in the usual way (see the KForge Guide
+   for details).
 """
 import kforge.plugin.base
 from kforge.ioc import *
