@@ -1,5 +1,24 @@
 """
-KForge Subversion plugin.
+KForge svn (subversion) plugin.
+
+Enabling this plugin allows users to create subversion services to provide
+subversion repositories for their project.
+
+## Installation ##
+
+1. Dependencies. To create services using this plugin you must have installed
+   the following external applications:
+
+   * subversion
+   * Apache modules to provide access to subversion through apache (e.g. on
+     debian the libapache2-svn package must be installed and the associated
+     modules enabled).
+
+2. KForge config file. You do not need to add anything to the KForge config
+   file.
+
+3. Install and enable this plugin in the usual way (see the KForge
+   Documentation for details)
 """
 import os
 import commands
