@@ -1,7 +1,17 @@
 """
-ProjectHome Plugin
+KForge www (project home) Plugin.
 
-This creates a project web directory that is accessible via dav.
+Enabling this plugin creates a project web directory (that is a directory on
+the file system the contents of which are displayed at the project's url on the
+KForge site). If the dav plugin is enabled then this directory will be
+accessible via dav.
+
+## Installation ##
+
+1. Dependencies. There are no dependencies beyond those required for KForge.
+
+2. KForge config file. You do not need to add anything to the KForge config
+   file.
 """
 import os
 import shutil
