@@ -6,13 +6,8 @@ import commands
 import shutil
 import sys
 
-def suite():
-    suites = [
-       unittest.makeSuite(InstallTest),
-       ]
-    return unittest.TestSuite(suites)
-
 class InstallTest(unittest.TestCase):
+    disable = True
 
     def setUp(self):
         """
