@@ -54,7 +54,6 @@ class UrlScheme(object):
                 action='login')
         self.mapper.connect('access_denied', 'accessDenied',
                 controller='accessDenied')
-        # for reasons that are unclear 
         self.mapper.connect('person', 'person/:action/:id',
                 controller='person', action='index',
                 requirements=dict(action='index|create|search|find|list|home')
@@ -83,16 +82,16 @@ class UrlScheme(object):
                 requirements=dict(subcontroller='services|members',
                     action='delete|edit|read')
                 )
-        # do not really need the controller here since this only ever used in
+        # do not really need the controller here since this map is only used in
         # url generation but need it for routes
         self.mapper.connect('project.service', ':project/:service',
-                controller='project.service')
+                controller='project.service', service=None)
         # this is not fully complete as we don't properly deal with subitems.
         # would like to have several maps and recurse but routes does not
         # support multiple mappers very nicely (if only url_for had a a config
         # argument ....)
-        self.mapper.connect('admin', 'admin/model/:offset',
-                controller='admin', action=None, offset=None
+        self.mapper.connect('admin', 'admin/:model/:offset',
+                controller='admin', model='model', action=None, offset=None
                 )
 
     def url_for(self, *args, **kwargs):
@@ -111,7 +110,11 @@ class UrlScheme(object):
         return url
 
     def getServicePath(self, service):
-        return self.url_for('project.service', project=service.project.name,
+        if service.plugin.name == 'www':
+            return self.url_for('project.service',
+                    project=service.project.name)
+        else:
+            return self.url_for('project.service', project=service.project.name,
                 service=service.name)
 
     def getServiceUrl(self, service):
