@@ -24,11 +24,11 @@ class UrlSchemeTest(TestCase):
     def _path(self, path):
         return self.prefix + path
 
-    def testBase(self):
+    def test_home(self):
         out = self.scheme.url_for('home')
         assert out == self._path('/')
 
-    def testMedia(self):
+    def test_media(self):
         out = self.scheme.url_for('media')
         assert out == self._path('/media')
         out = self.scheme.url_for('media', offset='/css/master.css')
@@ -37,7 +37,19 @@ class UrlSchemeTest(TestCase):
         exp = self._path('/media/css/master.css')
         assert exp in out
 
-    def testPerson(self):
+    def test_login(self):
+        out = self.scheme.url_for('login')
+        assert out == self._path('/login')
+
+    def test_logout(self):
+        out = self.scheme.url_for('logout')
+        assert out == self._path('/logout')
+
+    def test_accessDenied(self):
+        out = self.scheme.url_for('access_denied')
+        assert out == self._path('/accessDenied')
+
+    def test_person(self):
         out = self.scheme.url_for('person')
         assert out == self._path('/person')
         out = self.scheme.url_for('person', action='home')
@@ -49,7 +61,7 @@ class UrlSchemeTest(TestCase):
         out = self.scheme.url_for('person', action='delete', id=9)
         assert out == self._path('/person/9/delete')
 
-    def testProject(self):
+    def test_project(self):
         out = self.scheme.url_for('project')
         assert out == self._path('/project')
         out = self.scheme.url_for('project', action='search')
@@ -72,7 +84,7 @@ class UrlSchemeTest(TestCase):
 
     def test_admin(self):
         out = self.scheme.url_for('admin')
-        assert out == self._path('/admin/model')
+        assert out == self._path('/admin')
         out = self.scheme.url_for('admin', offset='Project/read/2')
         assert out == self._path('/admin/model/Project/read/2')
 
@@ -94,12 +106,19 @@ class UrlSchemeTest(TestCase):
         class ProjectStub:
             name = project_name
 
+        class PluginStub:
+            name = 'wiki'
+
         class ServiceStub:
             project = ProjectStub()
+            plugin = PluginStub()
             name = 'service_stub'
 
         out = self.scheme.getServicePath(ServiceStub())
         assert out == self._path('/%s/service_stub' % project_name)
+        PluginStub.name = 'www'
+        out = self.scheme.getServicePath(ServiceStub())
+        assert out == self._path('/%s' % project_name)
 
     def test_getServiceUrl(self):
         project_name = 'a_really_weird_name'
