@@ -3,6 +3,8 @@ import unittest
 import kforge.utils.mailer
 
 class TestSend(unittest.TestCase):
+    tags = [ 'cli' ]
+    disable = True
 
     def test_send(self):
         to = ['kforge-admin@localhost']
